@@ -74,59 +74,59 @@ DEFAULTS = {
 }
 
 ENVIRONMENT = {
-    'dist_dirs': None if not os.getenv('DIST') else os.getenv('DIST').split(','), #
-    'cache': os.getenv('CACHE'), #
-    'server_dir': os.getenv('SERVER_DIR'), #
-    'no_update': os.getenv('NO_UPDATE'), #
-    'prop_file': os.getenv('PROP_FILE'), #
-    'game_type': os.environ.get('PACK_NAME', os.environ.get('GAME_TYPE'.lower())), #
+    'dist_dirs': None if not os.getenv('DIST') else os.getenv('DIST').split(','),
+    'cache': os.getenv('CACHE'),
+    'server_dir': os.getenv('SERVER_DIR'),
+    'no_update': os.getenv('NO_UPDATE'),
+    'prop_file': os.getenv('PROP_FILE'),
+    'game_type': os.environ.get('PACK_NAME', os.environ.get('GAME_TYPE'.lower())),
     'minecraft_version': os.environ.get('VERSION'),
-    'pack_name': os.environ.get('PACK_NAME'), #
-    'pack_creator': os.environ.get('PACK_CREATOR'), #
-    'server_host': os.environ.get('SERVER_HOST'), #
-    'dest_email': os.environ.get('DEST_EMAIL'), #
-    'src_email': os.environ.get('SRC_EMAIL'), #
-    'mail_server': os.environ.get('MAIL_SERVER'), #
-    'mail_port': os.environ.get('MAIL_PORT'), #
-    'log_level': os.environ.get('LOG_LEVEL'), #
-    'log_dir': os.environ.get('LOG_DIR'), #
+    'pack_name': os.environ.get('PACK_NAME'),
+    'pack_creator': os.environ.get('PACK_CREATOR'),
+    'server_host': os.environ.get('SERVER_HOST'),
+    'dest_email': os.environ.get('DEST_EMAIL'),
+    'src_email': os.environ.get('SRC_EMAIL'),
+    'mail_server': os.environ.get('MAIL_SERVER'),
+    'mail_port': os.environ.get('MAIL_PORT'),
+    'log_level': os.environ.get('LOG_LEVEL'),
+    'log_dir': os.environ.get('LOG_DIR'),
     'java_params': {
-        'memory': os.getenv('JAVA_MEM'), #
-        'fml_confirm': os.getenv('FML_CONFIRM'), #
-        'log_level': os.getenv('MINECRAFT_LOG_LEVEL'), #
-        'log4j_xml': os.getenv('MINECRAFT_LOG4J_CONF') #
+        'memory': os.getenv('JAVA_MEM'),
+        'fml_confirm': os.getenv('FML_CONFIRM'),
+        'log_level': os.getenv('MINECRAFT_LOG_LEVEL'),
+        'log4j_xml': os.getenv('MINECRAFT_LOG4J_CONF')
     },
     'server_props': {
-        'motd': os.getenv('MOTD'), #
-        'server-port': os.getenv('SERVER_PORT'), #
-        'allow-nether': os.getenv('ALLOW_NETHER'), #
-        'announce-player-achievements': os.getenv('ANNOUNCE_PLAYER_ACHIEVEMENTS'), #
-        'enable-command-block': os.getenv('ENABLE_COMMAND_BLOCK'), #
-        'spawn-animals': os.getenv('SPAWN_ANIMALS'), #
-        'spawn-monsters': os.getenv('SPAWN_MONSTERS'), #
-        'spawn-npcs': os.getenv('SPAWN_NPCS'), #
-        'generate-structures': os.getenv('GENERATE_STRUCTURES'), #
-        'view-distance': os.getenv('VIEW_DISTANCE'), #
-        'hardcore': os.getenv('HARDCORE'), #
-        'max-build-height': os.getenv('MAX_BUILD_HEIGHT'), #
-        'force-gamemode': os.getenv('FORCE_GAMEMODE'), #
-        'max-tick-time': os.getenv('MAX_TICK_TIME'), #
-        'enable-query': os.getenv('ENABLE_QUERY'), #
-        'query.port': os.getenv('QUERY_PORT'), #
-        'enable-rcon': os.getenv('ENABLE_RCON'), #
-        'rcon.password': os.getenv('RCON_PASSWORD'), #
-        'rcon.port': os.getenv('RCON_PORT'), #
-        'max-players': os.getenv('MAX_PLAYERS'), #
-        'max-world-size': os.getenv('MAX_WORLD_SIZE'), #
-        'level-name': os.getenv('LEVEL_NAME'), #
-        'level-seed': os.getenv('LEVEL_SEED'), #
+        'motd': os.getenv('MOTD'),
+        'server-port': os.getenv('SERVER_PORT'),
+        'allow-nether': os.getenv('ALLOW_NETHER'),
+        'announce-player-achievements': os.getenv('ANNOUNCE_PLAYER_ACHIEVEMENTS'),
+        'enable-command-block': os.getenv('ENABLE_COMMAND_BLOCK'),
+        'spawn-animals': os.getenv('SPAWN_ANIMALS'),
+        'spawn-monsters': os.getenv('SPAWN_MONSTERS'),
+        'spawn-npcs': os.getenv('SPAWN_NPCS'),
+        'generate-structures': os.getenv('GENERATE_STRUCTURES'),
+        'view-distance': os.getenv('VIEW_DISTANCE'),
+        'hardcore': os.getenv('HARDCORE'),
+        'max-build-height': os.getenv('MAX_BUILD_HEIGHT'),
+        'force-gamemode': os.getenv('FORCE_GAMEMODE'),
+        'max-tick-time': os.getenv('MAX_TICK_TIME'),
+        'enable-query': os.getenv('ENABLE_QUERY'),
+        'query.port': os.getenv('QUERY_PORT'),
+        'enable-rcon': os.getenv('ENABLE_RCON'),
+        'rcon.password': os.getenv('RCON_PASSWORD'),
+        'rcon.port': os.getenv('RCON_PORT'),
+        'max-players': os.getenv('MAX_PLAYERS'),
+        'max-world-size': os.getenv('MAX_WORLD_SIZE'),
+        'level-name': os.getenv('LEVEL_NAME'),
+        'level-seed': os.getenv('LEVEL_SEED'),
         'pvp': os.getenv('PVP'), #
-        'generator-settings': os.getenv('GENERATOR_SETTINGS'), #
-        'online-mode': os.getenv('ONLINE_MODE'), #
-        'allow-flight': os.getenv('ALLOW_FLIGHT'), #
-        'level-type': os.getenv('LEVEL_TYPE'.upper()), #
-        'white-list': os.getenv('WHITELIST'), #
-        'spawn-protection': os.getenv('SPAWN_PROTECTION'), #
+        'generator-settings': os.getenv('GENERATOR_SETTINGS'),
+        'online-mode': os.getenv('ONLINE_MODE'),
+        'allow-flight': os.getenv('ALLOW_FLIGHT'),
+        'level-type': os.getenv('LEVEL_TYPE'.upper()),
+        'white-list': os.getenv('WHITELIST'),
+        'spawn-protection': os.getenv('SPAWN_PROTECTION'),
         'difficulty': os.getenv('DIFFICULTY'),
         'gamemode': os.getenv('GAMEMODE')
     }
@@ -765,7 +765,6 @@ class MineInit:
         :return:
         """
         arg_config = {
-            'verbose': args.verbose,
             'dist_dirs': args.dist_dirs,
             'cache': args.cache,
             'server_dir': args.server_dir,
